@@ -1,10 +1,11 @@
 """Handle file and directory operations."""
 
+import json
 import os
 import shutil
 import stat
 
-from nislmigrate.logging.migration_error import MigrationError
+from nislmigrate.logs.migration_error import MigrationError
 from nislmigrate.migration_action import MigrationAction
 
 
@@ -118,6 +119,17 @@ class FileSystemFacade:
         singlefile_full_path = os.path.join(migration_dir, file)
         shutil.copy(singlefile_full_path, restore_directory)
 
+    def read_json_file(self, path: str) -> dict:
+        """
+        Reads json from a file.
+
+        :param path: The path to the json file to read.
+        :return: The parsed json from the file.
+        """
+
+        with open(path, encoding="utf-8-sig") as json_file:
+            return json.load(json_file)
+
     @staticmethod
     def copy_file(from_directory: str, to_directory: str, file_name: str) -> None:
         """
